body {
    background: white;
}

#readmain {
    position: absolute;
    width: 100%;
    height: 100%;
}

#area {
    width: 80%;
    height: 80%;
    margin: 5% auto;
    max-width: 1250px;
}

#area iframe {
    border: none;
}

xmp, pre, plaintext {
    display: block;
    font-family: -moz-fixed;
    white-space: pre;
    margin: 1em 0;
}

#area{
    overflow:hidden;
}

pre {
    white-space: pre-wrap;
    word-wrap: break-word;
    font-family: -moz-fixed;
    column-count:2;
    -webkit-columns:2;
    -moz-columns:2;
    column-gap:20px;
    -moz-column-gap:20px;
    -webkit-column-gap:20px;
    position:relative;
}
