body.serieslist.grid-view div.container-fluid > div > div.col-sm-10::before {
  display: none;
}

.cover .badge {
  position: absolute;
  top: 0;
  left: 0;
  color: #fff;
  background-color: #cc7b19;
  border-radius: 0;
  padding: 0 8px;
  box-shadow: 0 0 4px rgba(0, 0, 0, 0.6);
  line-height: 24px;
}

.cover {
  box-shadow: 0 0 4px rgba(0, 0, 0, 0.6);
}

.cover .read {
  padding: 0 0;
  line-height: 15px;
}

input.datepicker {color: transparent}
input.datepicker:focus {color: transparent}
input.datepicker:focus + input {color: #555}

.col-sm-3.col-lg-2.col-xs-6.book.session {
    margin-left: 0;
    margin-right: 0;
}

@media only screen and (max-width: 767px) {
        .row-fluid > .col-sm-2 {
        visibility: hidden;
    }
}
