/*!
 * TinyMCE Language Pack
 *
 * Copyright (c) 2022 Ephox Corporation DBA Tiny Technologies, Inc.
 * Licensed under the Tiny commercial license. See https://www.tiny.cloud/legal/
 */
tinymce.addI18n('nb_NO', {
"Redo": "Gjør om",
"Undo": "Angre",
"Cut": "Klipp ut",
"Copy": "Kopier",
"Paste": "Lim inn",
"Select all": "Marker alt",
"New document": "Nytt dokument",
"Ok": "",
"Cancel": "Avbryt",
"Visual aids": "Visuelle hjelpemidler",
"Bold": "Fet",
"Italic": "Kursiv",
"Underline": "Understreking",
"Strikethrough": "Gjennomstreking",
"Superscript": "Hevet skrift",
"Subscript": "Senket skrift",
"Clear formatting": "Fjern formateringer",
"Remove": "",
"Align left": "Venstrejuster",
"Align center": "Midtstill",
"Align right": "Høyrejuster",
"No alignment": "",
"Justify": "Blokkjuster",
"Bullet list": "Punktliste",
"Numbered list": "Nummerliste",
"Decrease indent": "Reduser innrykk",
"Increase indent": "Øk innrykk",
"Close": "Lukk",
"Formats": "Stiler",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.": "Nettleseren din støtter ikke direkte tilgang til utklippsboken. Bruk istedet tastatursnarveiene Ctrl+X/C/V.",
"Headings": "Overskrifter",
"Heading 1": "Overskrift 1",
"Heading 2": "Overskrift 2",
"Heading 3": "Overskrift 3",
"Heading 4": "Overskrift 4",
"Heading 5": "Overskrift 5",
"Heading 6": "Overskrift 6",
"Preformatted": "Forhåndsformatert",
"Div": "",
"Pre": "",
"Code": "Kode",
"Paragraph": "Avsnitt",
"Blockquote": "",
"Inline": "Innkapslet",
"Blocks": "Blokker",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Lim inn er nå i ren tekst-modus. Kopiert innhold vil bli limt inn som ren tekst inntil du slår av dette valget.",
"Fonts": "Fonter",
"Font sizes": "",
"Class": "Klasse",
"Browse for an image": "Søk etter bilde",
"OR": "",
"Drop an image here": "Slipp et bilde her",
"Upload": "Last opp",
"Uploading image": "",
"Block": "Blokk",
"Align": "Juster",
"Default": "Standard",
"Circle": "Sirkel",
"Disc": "Disk",
"Square": "Firkant",
"Lower Alpha": "Små bokstaver",
"Lower Greek": "Greske minuskler",
"Lower Roman": "Små romertall",
"Upper Alpha": "Store bokstaver",
"Upper Roman": "Store romertall",
"Anchor...": "Lenke",
"Anchor": "",
"Name": "Navn",
"ID": "",
"ID should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "",
"You have unsaved changes are you sure you want to navigate away?": "Du har ikke arkivert endringene. Vil du fortsette uten å arkivere?",
"Restore last draft": "Gjenopprett siste utkast",
"Special character...": "Spesialtegn...",
"Special Character": "",
"Source code": "Kildekode",
"Insert/Edit code sample": "Sett inn / endre kodeeksempel",
"Language": "Språk",
"Code sample...": "Kodeeksempel",
"Left to right": "Venstre til høyre",
"Right to left": "Høyre til venstre",
"Title": "Tittel",
"Fullscreen": "Fullskjerm",
"Action": "Handling",
"Shortcut": "Snarvei",
"Help": "Hjelp",
"Address": "Adresse",
"Focus to menubar": "Fokus på menylinje",
"Focus to toolbar": "Fokus på verktøylinje",
"Focus to element path": "Fokus på elementsti",
"Focus to contextual toolbar": "Fokus på kontekstuell verktøylinje",
"Insert link (if link plugin activated)": "Sett inn lenke (dersom lenketillegg er aktivert)",
"Save (if save plugin activated)": "Lagre (dersom lagretillegg er aktivert)",
"Find (if searchreplace plugin activated)": "Finn (dersom tillegg for søk og erstatt er aktivert)",
"Plugins installed ({0}):": "Installerte tillegg ({0}):",
"Premium plugins:": "Premiumtillegg:",
"Learn more...": "Les mer ...",
"You are using {0}": "Du bruker {0}",
"Plugins": "Programtillegg",
"Handy Shortcuts": "Nyttige snarveier",
"Horizontal line": "Horisontal linje",
"Insert/edit image": "Sett inn / rediger bilde",
"Alternative description": "Alternativ beskrivelse",
"Accessibility": "Tilgjengelighet",
"Image is decorative": "Bilde er dekorasjon",
"Source": "Kilde",
"Dimensions": "Størrelser",
"Constrain proportions": "Begrens proporsjoner",
"General": "Generelt",
"Advanced": "Avansert",
"Style": "Stil",
"Vertical space": "Vertikal avstand",
"Horizontal space": "Horisontal avstand",
"Border": "Ramme",
"Insert image": "Sett inn bilde",
"Image...": "Bilde...",
"Image list": "Bildeliste",
"Resize": "Skaler",
"Insert date/time": "Sett inn dato/tid",
"Date/time": "Dato/tid",
"Insert/edit link": "Sett inn / rediger lenke",
"Text to display": "Tekst som skal vises",
"Url": "",
"Open link in...": "Åpne lenke i..",
"Current window": "Nåværende vindu",
"None": "Ingen",
"New window": "Nytt vindu",
"Open link": "Åpne lenke",
"Remove link": "Fjern lenke",
"Anchors": "Forankringspunkter",
"Link...": "Lenke...",
"Paste or type a link": "Lim inn eller skriv en lenke",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Oppgitt URL ser ut til å være en e-postadresse. Ønsker du å sette inn påkrevet mailto: prefiks foran e-postadressen?",
"The URL you entered seems to be an external link. Do you want to add the required http:// prefix?": "URL du skrev inn ser ut som en ekstern adresse. Vil du legge til det obligatoriske prefikset http://?",
"The URL you entered seems to be an external link. Do you want to add the required https:// prefix?": "Nettadressen du fylte inn ser ut til å være en ekstern. Ønsker du å legge til påkrevd 'https://'-prefiks?",
"Link list": "Liste over lenker",
"Insert video": "Sett inn video",
"Insert/edit video": "Sett inn / rediger video",
"Insert/edit media": "Sett inn / endre media",
"Alternative source": "Alternativ kilde",
"Alternative source URL": "Alternativ kilde URL",
"Media poster (Image URL)": "Mediaposter (bilde-URL)",
"Paste your embed code below:": "Lim inn inkluderingskoden nedenfor:",
"Embed": "Inkluder",
"Media...": "Media..",
"Nonbreaking space": "Hardt mellomrom",
"Page break": "Sideskifte",
"Paste as text": "Lim inn som tekst",
"Preview": "Forhåndsvis",
"Print": "",
"Print...": "Skriv ut...",
"Save": "Lagre",
"Find": "Søk etter",
"Replace with": "Erstatt med",
"Replace": "Erstatt",
"Replace all": "Erstatt alle",
"Previous": "Forrige",
"Next": "Neste",
"Find and Replace": "Finn og erstatt",
"Find and replace...": "Finn og erstatt...",
"Could not find the specified string.": "Kunne ikke finne den spesifiserte teksten",
"Match case": "Skill mellom store / små bokstaver",
"Find whole words only": "Finn kun hele ord",
"Find in selection": "Finn i utvalg",
"Insert table": "Sett inn tabell",
"Table properties": "Tabellegenskaper",
"Delete table": "Slett tabell",
"Cell": "Celle",
"Row": "Rad",
"Column": "Kolonne",
"Cell properties": "Celleegenskaper",
"Merge cells": "Slå sammen celler",
"Split cell": "Splitt celle",
"Insert row before": "Sett inn rad før",
"Insert row after": "Sett inn rad etter",
"Delete row": "Slett rad",
"Row properties": "Radegenskaper",
"Cut row": "Klipp ut rad",
"Cut column": "",
"Copy row": "Kopier rad",
"Copy column": "",
"Paste row before": "Lim inn rad før",
"Paste column before": "",
"Paste row after": "Lim inn rad etter",
"Paste column after": "",
"Insert column before": "Sett inn kolonne før",
"Insert column after": "Sett inn kolonne etter",
"Delete column": "Slett kolonne",
"Cols": "Kolonner",
"Rows": "Rader",
"Width": "Bredde",
"Height": "Høyde",
"Cell spacing": "Celleavstand",
"Cell padding": "Cellemarg",
"Row clipboard actions": "",
"Column clipboard actions": "",
"Table styles": "",
"Cell styles": "",
"Column header": "",
"Row header": "",
"Table caption": "",
"Caption": "Bildetekst",
"Show caption": "Vis bildetekst",
"Left": "Venstre",
"Center": "Senter",
"Right": "Høyre",
"Cell type": "Celletype",
"Scope": "Omfang",
"Alignment": "Justering",
"Horizontal align": "",
"Vertical align": "",
"Top": "Topp",
"Middle": "Sentrert",
"Bottom": "Bunn",
"Header cell": "Overskriftscelle",
"Row group": "Radgruppe",
"Column group": "Kolonnegruppe",
"Row type": "Radtype",
"Header": "",
"Body": "Brødtekst",
"Footer": "Bunntekst",
"Border color": "Rammefarge",
"Solid": "",
"Dotted": "",
"Dashed": "",
"Double": "",
"Groove": "",
"Ridge": "",
"Inset": "",
"Outset": "",
"Hidden": "",
"Insert template...": "Sett inn mal..",
"Templates": "Maler",
"Template": "Mal",
"Insert Template": "",
"Text color": "Tekstfarge",
"Background color": "Bakgrunnsfarge",
"Custom...": "Tilpasset...",
"Custom color": "Tilpasset farge",
"No color": "Ingen farge",
"Remove color": "Fjern farge",
"Show blocks": "Vis blokker",
"Show invisible characters": "Vis skjulte tegn",
"Word count": "Ordtelling",
"Count": "Opptelling",
"Document": "Dokument",
"Selection": "Utvalg",
"Words": "Ord",
"Words: {0}": "Ord: {0}",
"{0} words": "{0} ord",
"File": "Fil",
"Edit": "Rediger",
"Insert": "Sett inn",
"View": "Vis",
"Format": "",
"Table": "Tabell",
"Tools": "Verktøy",
"Powered by {0}": "Drevet av {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Tekstredigering. Tast ALT-F9 for meny. Tast ALT-F10 for verktøylinje. Tast ALT-0 for hjelp.",
"Image title": "Bildetittel",
"Border width": "Bordbredde",
"Border style": "Bordstil",
"Error": "Feil",
"Warn": "Advarsel",
"Valid": "Gyldig",
"To open the popup, press Shift+Enter": "For å åpne popup, trykk Shift+Enter",
"Rich Text Area": "",
"Rich Text Area. Press ALT-0 for help.": "Rik-tekstområde. Trykk ALT-0 for hjelp.",
"System Font": "Systemfont",
"Failed to upload image: {0}": "Opplasting av bilde feilet: {0}",
"Failed to load plugin: {0} from url {1}": "Kunne ikke laste tillegg: {0} from url {1}",
"Failed to load plugin url: {0}": "Kunne ikke laste tillegg url: {0}",
"Failed to initialize plugin: {0}": "Kunne ikke initialisere tillegg: {0}",
"example": "eksempel",
"Search": "Søk",
"All": "Alle",
"Currency": "Valuta",
"Text": "Tekst",
"Quotations": "Sitater",
"Mathematical": "Matematisk",
"Extended Latin": "Utvidet latin",
"Symbols": "Symboler",
"Arrows": "Piler",
"User Defined": "Brukerdefinert",
"dollar sign": "dollartegn",
"currency sign": "valutasymbol",
"euro-currency sign": "Euro-valutasymbol",
"colon sign": "kolon-symbol",
"cruzeiro sign": "cruzeiro-symbol",
"french franc sign": "franske franc-symbol",
"lira sign": "lire-symbol",
"mill sign": "mill-symbol",
"naira sign": "naira-symbol",
"peseta sign": "peseta-symbol",
"rupee sign": "rupee-symbol",
"won sign": "won-symbol",
"new sheqel sign": "Ny sheqel-symbol",
"dong sign": "dong-symbol",
"kip sign": "kip-symbol",
"tugrik sign": "tugrik-symbol",
"drachma sign": "drachma-symbol",
"german penny symbol": "tysk penny-symbol",
"peso sign": "peso-symbol",
"guarani sign": "quarani-symbol",
"austral sign": "austral-symbol",
"hryvnia sign": "hryvina-symbol",
"cedi sign": "credi-symbol",
"livre tournois sign": "livre tournois-symbol",
"spesmilo sign": "spesmilo-symbol",
"tenge sign": "tenge-symbol",
"indian rupee sign": "indisk rupee-symbol",
"turkish lira sign": "tyrkisk lire-symbol",
"nordic mark sign": "nordisk mark-symbol",
"manat sign": "manat-symbol",
"ruble sign": "ruble-symbol",
"yen character": "yen-symbol",
"yuan character": "yuan-symbol",
"yuan character, in hong kong and taiwan": "yuan-symbol, i Hongkong og Taiwan",
"yen/yuan character variant one": "yen/yuan-symbol variant en",
"Emojis": "",
"Emojis...": "",
"Loading emojis...": "",
"Could not load emojis": "",
"People": "Mennesker",
"Animals and Nature": "Dyr og natur",
"Food and Drink": "Mat og drikke",
"Activity": "Aktivitet",
"Travel and Places": "Reise og steder",
"Objects": "Objekter",
"Flags": "Flagg",
"Characters": "Tegn",
"Characters (no spaces)": "Tegn (uten mellomrom)",
"{0} characters": "{0} tegn",
"Error: Form submit field collision.": "Feil: Skjemafelt innsendingskollisjon.",
"Error: No form element found.": "Feil: Intet skjemafelt funnet.",
"Color swatch": "Fargepalett",
"Color Picker": "Fargevelger",
"Invalid hex color code: {0}": "",
"Invalid input": "",
"R": "",
"Red component": "",
"G": "",
"Green component": "",
"B": "",
"Blue component": "",
"#": "",
"Hex color code": "",
"Range 0 to 255": "",
"Turquoise": "Turkis",
"Green": "Grønn",
"Blue": "Blå",
"Purple": "Lilla",
"Navy Blue": "Marineblå",
"Dark Turquoise": "Mørk turkis",
"Dark Green": "Mørkegrønn",
"Medium Blue": "Mellomblå",
"Medium Purple": "Medium lilla",
"Midnight Blue": "Midnattblå",
"Yellow": "Gul",
"Orange": "Oransje",
"Red": "Rød",
"Light Gray": "Lys grå",
"Gray": "Grå",
"Dark Yellow": "Mørk gul",
"Dark Orange": "Mørk oransje",
"Dark Red": "Mørkerød",
"Medium Gray": "Medium grå",
"Dark Gray": "Mørk grå",
"Light Green": "Lys grønn",
"Light Yellow": "Lys gul",
"Light Red": "Lys rød",
"Light Purple": "Lys lilla",
"Light Blue": "Lys blå",
"Dark Purple": "Mørk lilla",
"Dark Blue": "Mørk blå",
"Black": "Svart",
"White": "Hvit",
"Switch to or from fullscreen mode": "Bytt til eller fra fullskjermmodus",
"Open help dialog": "Åpne hjelp-dialog",
"history": "historikk",
"styles": "stiler",
"formatting": "formatering",
"alignment": "justering",
"indentation": "innrykk",
"Font": "Skrift",
"Size": "Størrelse",
"More...": "Mer...",
"Select...": "Velg...",
"Preferences": "Innstillinger",
"Yes": "Ja",
"No": "Nei",
"Keyboard Navigation": "Navigering med tastaturet",
"Version": "Versjon",
"Code view": "Kodevisning",
"Open popup menu for split buttons": "Åpne sprettoppmeny for splitt-knapper",
"List Properties": "Listeegenskaper",
"List properties...": "Listeegenskaper ...",
"Start list at number": "Start liste på nummer",
"Line height": "Linjehøyde",
"Dropped file type is not supported": "",
"Loading...": "",
"ImageProxy HTTP error: Rejected request": "",
"ImageProxy HTTP error: Could not find Image Proxy": "",
"ImageProxy HTTP error: Incorrect Image Proxy URL": "",
"ImageProxy HTTP error: Unknown ImageProxy error": ""
});