{% extends "layout.html" %}
{% block body %}
<div class="well">
  <input type="hidden" name="csrf_token" value="{{ csrf_token() }}">
  <h2 style="margin-top: 0">{{_('Magic Link - Authorise New Device')}}</h2>
  <p>
    {{_('On another device, login and visit:')}}
  <h4><a id="verify_url" data-token="{{token}}" href="{{verify_url}}">{{verify_url}}</a><b></b>
  </h4>
  <p>
    {{_('Once verified, you will automatically be logged in on this device.')}}
  </p>
  <p>
    {{_('This verification link will expire in 10 minutes.')}}
  </p>
</div>
{% endblock %}

{% block js %}
    <script src="{{ url_for('static', filename='js/remote_login.js') }}"></script>
{% endblock %}
