{% extends "layout.html" %}
{% block body %}
  <h3>{{_('About')}} {{instance}}</h3>
<p>{{instance}} powered by
<a href="https://github.com/janeczku/calibre-web" title="Calibre-Web">Calibre-Web</a>.
</p>
  <h3>{{_('Library Statistics')}}</h3>
<table id="stats" class="table">
  <tbody>
    <tr>
      <th>{{bookcounter}}</th>
      <td>{{_('Books in this Library')}}</td>
    </tr>
    <tr>
      <th>{{authorcounter}}</th>
      <td>{{_('Authors in this Library')}}</td>
    </tr>
    <tr>
      <th>{{categorycounter}}</th>
      <td>{{_('Categories in this Library')}}</td>
    </tr>
    <tr>
      <th>{{seriecounter}}</th>
      <td>{{_('Series in this Library')}}</td>
    </tr>
  </tbody>
</table>
{% if current_user.role_admin() %}
  <h3>{{_('System Statistics')}}</h3>
<table id="libs" class="table">
  <thead>
    <tr>
      <th>{{_('Program')}}</th>
      <th>{{_('Installed Version')}}</th>
    </tr>
  </thead>
  <tbody>
  {% for library,version in versions.items() %}
  {% if version %}
    <tr>
      <th>{{library}}</th>
      <td>{{version}}</td>
    </tr>
  {% endif %}
  {% endfor %}
  </tbody>
</table>
{% endif %}
{% endblock %}
