tinymce.addI18n('et',{
"Redo": "Tee uuesti",
"Undo": "V\u00f5ta tagasi",
"Cut": "L\u00f5ika",
"Copy": "Kopeeri",
"Paste": "Kleebi",
"Select all": "Vali k\u00f5ik",
"New document": "Uus dokument",
"Ok": "Ok",
"Cancel": "Katkesta",
"Visual aids": "N\u00e4itevahendid",
"Bold": "Rasvane",
"Italic": "Kaldkiri",
"Underline": "Allakriipsutatud",
"Strikethrough": "L\u00e4bikriipsutatud",
"Superscript": "\u00dclaindeks",
"Subscript": "Alaindeks",
"Clear formatting": "Puhasta vorming",
"Align left": "Joonda vasakule",
"Align center": "Joonda keskele",
"Align right": "Joonda paremale",
"Justify": "Joonda r\u00f6\u00f6pselt",
"Bullet list": "J\u00e4rjestamata loend",
"Numbered list": "J\u00e4rjestatud loend",
"Decrease indent": "V\u00e4henda taanet",
"Increase indent": "Suurenda taanet",
"Close": "Sulge",
"Formats": "Vormingud",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Sinu veebilehitseja ei toeta otsest ligip\u00e4\u00e4su l\u00f5ikelauale. Palun kasuta selle asemel klaviatuuri kiirk\u00e4sklusi Ctrl+X\/C\/V.",
"Headers": "P\u00e4ised",
"Header 1": "Pealkiri 1",
"Header 2": "Pealkiri 2",
"Header 3": "Pealkiri 3",
"Header 4": "Pealkiri 4",
"Header 5": "Pealkiri 5",
"Header 6": "Pealkiri 6",
"Headings": "Pealkirjad",
"Heading 1": "Pealkiri 1",
"Heading 2": "Pealkiri 2",
"Heading 3": "Pealkiri 3",
"Heading 4": "Pealkiri 4",
"Heading 5": "Pealkiri 5",
"Heading 6": "Pealkiri 6",
"Preformatted": "Eelvormindaud",
"Div": "Sektsioon",
"Pre": "Eelvormindatud",
"Code": "Kood",
"Paragraph": "L\u00f5ik",
"Blockquote": "Plokktsitaat",
"Inline": "Reasisene",
"Blocks": "Plokid",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Asetamine on n\u00fc\u00fcd tekstire\u017eiimis. Sisu asetatakse n\u00fc\u00fcd lihttekstina, kuni sa l\u00fclitad selle valiku v\u00e4lja.",
"Fonts": "Fondid",
"Font Sizes": "Kirja suurused",
"Class": "Klass",
"Browse for an image": "Sirvi pilte",
"OR": "V\u00d5I",
"Drop an image here": "Kukuta pilt siia",
"Upload": "\u00dcles laadimine",
"Block": "Plokk",
"Align": "Joonda",
"Default": "Vaikimisi",
"Circle": "Ring",
"Disc": "Ketas",
"Square": "Ruut",
"Lower Alpha": "V\u00e4iket\u00e4hed (a, b, c)",
"Lower Greek": "Kreeka v\u00e4iket\u00e4hed (\u03b1, \u03b2, \u03b3)",
"Lower Roman": "Rooma v\u00e4iket\u00e4hed (i, ii, iii)",
"Upper Alpha": "Suurt\u00e4hed (A, B, C)",
"Upper Roman": "Rooma suurt\u00e4hed (I, II, III)",
"Anchor...": "Ankur ...",
"Name": "Nimi",
"Id": "ID",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "ID peaks algama t\u00e4hega ning sellele peaks j\u00e4rgnema ainult t\u00e4hed, arvud, sidekriipsud, punktid, koolonid v\u00f5i alakriipsud.",
"You have unsaved changes are you sure you want to navigate away?": "Sul on salvestamata muudatusi. Oled Sa kindel, et soovid mujale navigeeruda?",
"Restore last draft": "Taasta viimane mustand",
"Special character...": "Eriline tegelane ...",
"Source code": "L\u00e4htekood",
"Insert\/Edit code sample": "Sisesta\/muuda koodin\u00e4idis",
"Language": "Keel",
"Code sample...": "Koodin\u00e4ide ...",
"Color Picker": "V\u00e4rvivalija",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Vasakult paremale",
"Right to left": "Paremalt vasakule",
"Emoticons...": "Emotikonid ...",
"Metadata and Document Properties": "Metaandmed ja dokumendi atribuudid",
"Title": "Pealkiri",
"Keywords": "M\u00e4rks\u00f5nad",
"Description": "Kirjeldus",
"Robots": "Robotid",
"Author": "Autor",
"Encoding": "M\u00e4rgistik",
"Fullscreen": "T\u00e4isekraan",
"Action": "Tegevus",
"Shortcut": "Otsetee",
"Help": "Abiinfo",
"Address": "Aadress",
"Focus to menubar": "Fookus men\u00fc\u00fcribale",
"Focus to toolbar": "Fookus t\u00f6\u00f6riistaribale",
"Focus to element path": "Fookus elemendi asukohale",
"Focus to contextual toolbar": "Fookus kontekstimen\u00fc\u00fcle",
"Insert link (if link plugin activated)": "Sisesta link (kui lingi plugin on aktiveeritud)",
"Save (if save plugin activated)": "Salvesta (kui salvestamise plugin on aktiveeritud)",
"Find (if searchreplace plugin activated)": "Otsi (kui plugin searchreplace on aktiveeritud)",
"Plugins installed ({0}):": "Pluginad on paigaldatud ({0}):",
"Premium plugins:": "Tasulised pluginad:",
"Learn more...": "Vaata lisainfot...",
"You are using {0}": "Sa kasutad {0}",
"Plugins": "Pluginad",
"Handy Shortcuts": "Mugavad otseteed",
"Horizontal line": "Horisontaaljoon",
"Insert\/edit image": "Lisa\/muuda pilt",
"Image description": "Pildi kirjeldus",
"Source": "Allikas",
"Dimensions": "M\u00f5\u00f5tmed",
"Constrain proportions": "S\u00e4ilita kuvasuhe",
"General": "\u00dcldine",
"Advanced": "T\u00e4iendavad seaded",
"Style": "Stiil",
"Vertical space": "P\u00fcstine vahe",
"Horizontal space": "Reavahe",
"Border": "\u00c4\u00e4ris",
"Insert image": "Lisa pilt",
"Image...": "Pilt ...",
"Image list": "Piltide nimekiri",
"Rotate counterclockwise": "P\u00f6\u00f6ra vastup\u00e4eva",
"Rotate clockwise": "P\u00f6\u00f6ra p\u00e4rip\u00e4eva",
"Flip vertically": "Peegelda vertikaalselt",
"Flip horizontally": "Peegelda horisontaalselt",
"Edit image": "Muuda pilti",
"Image options": "Pildi valikud",
"Zoom in": "Suumi sisse",
"Zoom out": "Suumi v\u00e4lja",
"Crop": "L\u00f5ika",
"Resize": "Muuda suurust",
"Orientation": "Suund",
"Brightness": "Heledus",
"Sharpen": "Teravamaks",
"Contrast": "Kontrast",
"Color levels": "V\u00e4rvi tasemed",
"Gamma": "Gamma",
"Invert": "P\u00f6\u00f6ra v\u00e4rvid",
"Apply": "Rakenda",
"Back": "Tagasi",
"Insert date\/time": "Lisa kuup\u00e4ev\/kellaaeg",
"Date\/time": "Kuup\u00e4ev\/kellaaeg",
"Insert\/Edit Link": "Lingi lisamine \/ muutmine",
"Insert\/edit link": "Lisa\/muuda link",
"Text to display": "Kuvatav tekst",
"Url": "Viide (url)",
"Open link in...": "Ava link saidil ...",
"Current window": "Praegune aken",
"None": "Puudub",
"New window": "Uus aken",
"Remove link": "Eemalda link",
"Anchors": "Ankrud",
"Link...": "Link...",
"Paste or type a link": "Aseta v\u00f5i sisesta link",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "URL, mille sa sisestasid, n\u00e4ib olevat e-posti aadress. Kas sa soovid lisada sellele eesliite mailto: ?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "URL, mille sa sisestasid, n\u00e4ib olevat v\u00e4line link. Kas sa soovid lisada sellele eesliite http:\/\/ ?",
"Link list": "Linkide nimekiri",
"Insert video": "Lisa video",
"Insert\/edit video": "Lisa\/muuda video",
"Insert\/edit media": "Lisa\/muuda multimeediat",
"Alternative source": "Teine allikas",
"Alternative source URL": "Alternatiivne allika URL",
"Media poster (Image URL)": "Meediaplakat (pildi URL)",
"Paste your embed code below:": "Kleebi oma manustamiskood siia alla:",
"Embed": "Manusta",
"Media...": "Meedia ...",
"Nonbreaking space": "T\u00fchim\u00e4rk (nbsp)",
"Page break": "Lehevahetus",
"Paste as text": "Aseta tekstina",
"Preview": "Eelvaade",
"Print...": "Prindi ...",
"Save": "Salvesta",
"Find": "Otsi",
"Replace with": "Asendus",
"Replace": "Asenda",
"Replace all": "Asenda k\u00f5ik",
"Previous": "Eelmine",
"Next": "J\u00e4rg",
"Find and replace...": "Leidke ja asendage ...",
"Could not find the specified string.": "Ei suutnud leida etteantud s\u00f5net.",
"Match case": "Erista suur- ja v\u00e4iket\u00e4hti",
"Find whole words only": "Leidke ainult terved s\u00f5nad",
"Spell check": "\u00d5igekirja kontroll",
"Ignore": "Eira",
"Ignore all": "Eira k\u00f5iki",
"Finish": "L\u00f5peta",
"Add to Dictionary": "Lisa s\u00f5naraamatusse",
"Insert table": "Lisa tabel",
"Table properties": "Tabeli omadused",
"Delete table": "Kustuta tabel",
"Cell": "Lahter",
"Row": "Rida",
"Column": "Tulp",
"Cell properties": "Lahtri omadused",
"Merge cells": "\u00dchenda lahtrid",
"Split cell": "T\u00fckelda lahter",
"Insert row before": "Lisa rida enne",
"Insert row after": "Lisa rida j\u00e4rele",
"Delete row": "Kustuta rida",
"Row properties": "Rea omadused",
"Cut row": "L\u00f5ika rida",
"Copy row": "Kopeeri rida",
"Paste row before": "Kleebi rida enne",
"Paste row after": "Kleebi rida j\u00e4rele",
"Insert column before": "Lisa tulp enne",
"Insert column after": "Lisa tulp j\u00e4rele",
"Delete column": "Kustuta tulp",
"Cols": "Veerud",
"Rows": "Read",
"Width": "Laius",
"Height": "K\u00f5rgus",
"Cell spacing": "Lahtrivahe",
"Cell padding": "Lahtri sisu ja tabeli \u00e4\u00e4rise vahe",
"Show caption": "Kuva pealdis",
"Left": "Vasakul",
"Center": "Keskel",
"Right": "Paremal",
"Cell type": "Lahtri t\u00fc\u00fcp",
"Scope": "Ulatus",
"Alignment": "Joondus",
"H Align": "H Joondus",
"V Align": "V Joondus",
"Top": "\u00dcleval",
"Middle": "Keskel",
"Bottom": "All",
"Header cell": "P\u00e4islahter",
"Row group": "Ridade r\u00fchm",
"Column group": "Veergude r\u00fchm",
"Row type": "Rea t\u00fc\u00fcp",
"Header": "P\u00e4is",
"Body": "P\u00f5hiosa",
"Footer": "Jalus",
"Border color": "Piirjoone v\u00e4rv",
"Insert template...": "Sisesta mall ...",
"Templates": "Mallid",
"Template": "Mall",
"Text color": "Teksti v\u00e4rv",
"Background color": "Tausta v\u00e4rv",
"Custom...": "Kohandatud...",
"Custom color": "Kohandatud v\u00e4rv",
"No color": "V\u00e4rvi pole",
"Remove color": "Eemaldage v\u00e4rv",
"Table of Contents": "Sisukord",
"Show blocks": "N\u00e4ita plokke",
"Show invisible characters": "N\u00e4ita peidetud m\u00e4rke",
"Word count": "S\u00f5nade arv",
"Count": "Krahv",
"Document": "Dokument",
"Selection": "Valik",
"Words": "S\u00f5nad",
"Words: {0}": "S\u00f5nu: {0}",
"{0} words": "{0} s\u00f5na",
"File": "Fail",
"Edit": "Muuda",
"Insert": "Sisesta",
"View": "Vaade",
"Format": "Vorming",
"Table": "Tabel",
"Tools": "T\u00f6\u00f6riistad",
"Powered by {0}": "Kasutatud tarkvara {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rikastatud teksti ala. Men\u00fc\u00fc jaoks vajuta ALT-F9. T\u00f6\u00f6riistariba jaoks vajuta ALT-F10. Abi saamiseks vajuta ALT-0.",
"Image title": "Pildi pealkiri",
"Border width": "\u00c4\u00e4rise laius",
"Border style": "Piiri stiil",
"Error": "Viga",
"Warn": "Hoiatage",
"Valid": "Kehtib",
"To open the popup, press Shift+Enter": "H\u00fcpikakna avamiseks vajutage t\u00f5stuklahvi + sisestusklahvi",
"Rich Text Area. Press ALT-0 for help.": "Rikasteksti ala. Abi saamiseks vajutage ALT-0.",
"System Font": "S\u00fcsteemi font",
"Failed to upload image: {0}": "Pildi \u00fcleslaadimine eba\u00f5nnestus: {0}",
"Failed to load plugin: {0} from url {1}": "Pistikprogrammi laadimine nurjus: {0} URL-ist {1}",
"Failed to load plugin url: {0}": "Pistikprogrammi URL-i laadimine nurjus: {0}",
"Failed to initialize plugin: {0}": "Pistikprogrammi l\u00e4htestamine eba\u00f5nnestus: {0}",
"example": "n\u00e4ide",
"Search": "Otsing",
"All": "K\u00f5ik",
"Currency": "Valuuta",
"Text": "Tekst",
"Quotations": "Tsitaadid",
"Mathematical": "Matemaatiline",
"Extended Latin": "Laiendatud ladina keel",
"Symbols": "S\u00fcmbolid",
"Arrows": "Nooled",
"User Defined": "Kasutaja m\u00e4\u00e4ratud",
"dollar sign": "dollari m\u00e4rk",
"currency sign": "v\u00e4\u00e4ringu m\u00e4rk",
"euro-currency sign": "euro v\u00e4\u00e4ringu m\u00e4rk",
"colon sign": "j\u00e4mesoole m\u00e4rk",
"cruzeiro sign": "cruzeiro m\u00e4rk",
"french franc sign": "Prantsuse frangi m\u00e4rk",
"lira sign": "liiri m\u00e4rk",
"mill sign": "veskim\u00e4rk",
"naira sign": "naira m\u00e4rk",
"peseta sign": "peseta m\u00e4rk",
"rupee sign": "ruupia m\u00e4rk",
"won sign": "v\u00f5itis m\u00e4rgi",
"new sheqel sign": "uus \u0161ekeli m\u00e4rk",
"dong sign": "dongi m\u00e4rk",
"kip sign": "kip m\u00e4rk",
"tugrik sign": "tugriku m\u00e4rk",
"drachma sign": "drahmam\u00e4rk",
"german penny symbol": "saksa senti s\u00fcmbol",
"peso sign": "peeso m\u00e4rk",
"guarani sign": "guarani m\u00e4rk",
"austral sign": "austraalne m\u00e4rk",
"hryvnia sign": "grivna m\u00e4rk",
"cedi sign": "cedi m\u00e4rk",
"livre tournois sign": "elav turniiri m\u00e4rk",
"spesmilo sign": "spesmilo m\u00e4rk",
"tenge sign": "tenge m\u00e4rk",
"indian rupee sign": "India ruupia m\u00e4rk",
"turkish lira sign": "t\u00fcrgi liiri m\u00e4rk",
"nordic mark sign": "p\u00f5hjam\u00e4rgi m\u00e4rk",
"manat sign": "manati m\u00e4rk",
"ruble sign": "rubla m\u00e4rk",
"yen character": "jeeni tegelaskuju",
"yuan character": "j\u00fcaani tegelaskuju",
"yuan character, in hong kong and taiwan": "j\u00fcaani tegelane, Hongkongis ja Taiwanis",
"yen\/yuan character variant one": "jeeni \/ j\u00fcaani t\u00e4hem\u00e4rgi variant \u00fcks",
"Loading emoticons...": "Emotikonide laadimine ...",
"Could not load emoticons": "Emotikonide laadimine nurjus",
"People": "Inimesed",
"Animals and Nature": "Loomad ja loodus",
"Food and Drink": "Toit ja jook",
"Activity": "Tegevus",
"Travel and Places": "Reisimine ja kohad",
"Objects": "Objektid",
"Flags": "Lipud",
"Characters": "Tegelased",
"Characters (no spaces)": "M\u00e4rgid (t\u00fchikud puuduvad)",
"{0} characters": "{0} t\u00e4hem\u00e4rki",
"Error: Form submit field collision.": "Viga: vormi esitamise v\u00e4lja kokkup\u00f5rge.",
"Error: No form element found.": "Viga: vormielementi ei leitud.",
"Update": "Uuenda",
"Color swatch": "V\u00e4rvivalik",
"Turquoise": "T\u00fcrkiis",
"Green": "Roheline",
"Blue": "Sinine",
"Purple": "Lilla",
"Navy Blue": "Merev\u00e4e sinine",
"Dark Turquoise": "Tume t\u00fcrkiissinine",
"Dark Green": "Tumeroheline",
"Medium Blue": "Keskmine sinine",
"Medium Purple": "Keskmine lilla",
"Midnight Blue": "Kesk\u00f6ine sinine",
"Yellow": "Kollane",
"Orange": "Oran\u017e",
"Red": "Punane",
"Light Gray": "Helehall",
"Gray": "Hall",
"Dark Yellow": "Tumekollane",
"Dark Orange": "Tumeoran\u017e",
"Dark Red": "Tumepunane",
"Medium Gray": "Keskmiselt hall",
"Dark Gray": "Tumehall",
"Light Green": "Heleroheline",
"Light Yellow": "Helekollane",
"Light Red": "Helepunane",
"Light Purple": "Helelilla",
"Light Blue": "Helesinine",
"Dark Purple": "Tumelilla",
"Dark Blue": "Tumesinine",
"Black": "Must",
"White": "Valge",
"Switch to or from fullscreen mode": "L\u00fclitumine t\u00e4isekraanre\u017eiimile v\u00f5i sellest v\u00e4lja",
"Open help dialog": "Ava dialoog",
"history": "ajalugu",
"styles": "stiilid",
"formatting": "vormindamine",
"alignment": "joondamine",
"indentation": "taane",
"permanent pen": "p\u00fcsiv pliiats",
"comments": "kommentaare",
"Format Painter": "Format Painter",
"Insert\/edit iframe": "Sisesta \/ redigeeri iframe",
"Capitalization": "Suurt\u00e4htede kasutamine",
"lowercase": "v\u00e4iket\u00e4hed",
"UPPERCASE": "\u00dcLEMINEK",
"Title Case": "Pealkirja juhtum",
"Permanent Pen Properties": "P\u00fcsivad pliiatsi omadused",
"Permanent pen properties...": "Pliiatsi p\u00fcsivad omadused ...",
"Font": "Font",
"Size": "Suurus",
"More...": "Veel ...",
"Spellcheck Language": "\u00d5igekirjakontroll",
"Select...": "Valige ...",
"Preferences": "Eelistused",
"Yes": "Jah",
"No": "Ei",
"Keyboard Navigation": "Klaviatuuril navigeerimine",
"Version": "Versioon",
"Anchor": "Ankur",
"Special character": "Erim\u00e4rk",
"Code sample": "Koodi n\u00e4idis",
"Color": "V\u00e4rv",
"Emoticons": "Emotikonid",
"Document properties": "Dokumendi omadused",
"Image": "Pilt",
"Insert link": "Lisa link",
"Target": "Sihtm\u00e4rk",
"Link": "Link",
"Poster": "Lisaja",
"Media": "Multimeedia",
"Print": "Tr\u00fcki",
"Prev": "Eelm",
"Find and replace": "Otsi ja asenda",
"Whole words": "Terviks\u00f5nad",
"Spellcheck": "\u00d5igekirja kontroll",
"Caption": "Alapealkiri",
"Insert template": "Lisa mall"
});